@@ -4,8 +4,9 @@ use strict;
 use warnings;
 use base qw( Catalyst::Controller::HTML::FormFu::ActionBase::Form );
 
+our $VERSION = '1.00_01'; # TRIAL VERSION
+
 use Config::Any;
-use MRO::Compat;
 
 sub execute {
     my $self = shift;
