@@ -4,7 +4,8 @@ use strict;
 use warnings;
 use base qw( Catalyst::Controller::HTML::FormFu::ActionBase::Form );
 
-use MRO::Compat;
+our $VERSION = '1.00_01'; # TRIAL VERSION
+
 use Carp qw( croak );
 
 sub execute {
