@@ -1,4 +1,9 @@
 package HTML::FormFu::Constraint::RequestToken;
+
+use strict;
+
+our $VERSION = '1.00_01'; # TRIAL VERSION
+
 use Moose;
 
 extends 'HTML::FormFu::Constraint';
